==> insuideindoor-1.0.9.tar.gz: example/lib/kkk/splash.dart <==
import 'package:flutter/services.dart';
import 'package:location/location.dart';
import 'package:flutter/material.dart';

import 'package:mapbox_gl/mapbox_gl.dart';
import 'package:mapbox_gl_example/kkk/final_home.dart';
import 'package:mapbox_gl_example/main.dart';

LatLng GetLatLngFromSP() {
  return LatLng(sharedPreferences.getDouble('latitude')!,
      sharedPreferences.getDouble('longitude')!);
}

class Splash extends StatefulWidget {
  const Splash({Key? key}) : super(key: key);

  @override
  State<Splash> createState() => _SplashState();
}

class _SplashState extends State<Splash> {
  // bool isLoadingIA = true;
  LatLng? IAcoordinates;
  @override
  void initState() {
    super.initState();
    initializeLocationAndSave();
    fetchCurrentLocationViaIA();
  }

  fetchCurrentLocationViaIA() {
    const Channel = MethodChannel("com.mapbox.mapboxglexample");
    const platform = const MethodChannel("com.mapbox.mapboxglexample");

    platform.setMethodCallHandler((call) async {
      print("init state setMethodCallHandler ${call.arguments}");
      // setState(() {
      //   IAcoordinates = call.arguments;
      //   //sharedPreferences.setString('latLng', IAcoordinates.toString());
      // });

      Navigator.pushAndRemoveUntil(
          context,
          // MaterialPageRoute(builder: (_) => MyHome(data: call.arguments)),
          MaterialPageRoute(builder: (_) => FinalHome()),
          // Home2()),
          (route) => false);
    });
  }

  void initializeLocationAndSave() async {
    // Ensure all permissions are collected for Locations
    Location location = Location();
    bool serviceEnabled;
    PermissionStatus? permissionGranted;

    serviceEnabled = await location.serviceEnabled();
    if (!serviceEnabled) {
      serviceEnabled = await location.requestService();
    }

    permissionGranted = await location.hasPermission();
    if (permissionGranted == PermissionStatus.denied) {
      permissionGranted = await location.requestPermission();
    }

    // Get the current user location
    LocationData _locationData = await location.getLocation();
    LatLng currentLocation =
        LatLng(_locationData.latitude!, _locationData.longitude!);

    // Get the current user address
    // String currentAddress =
    //     (await getParsedReverseGeocoding(currentLocation))['place'];

    // Store the user location in sharedPreferences
    sharedPreferences.setDouble('latitude', _locationData.latitude!);
    sharedPreferences.setDouble('longitude', _locationData.longitude!);

    // sharedPreferences.setString('current-address', currentAddress);

    // ignore: use_build_context_synchronously
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: const [
          Center(child: CircularProgressIndicator()),
          SizedBox(height: 20),
          Text("Fetching Location Details")
        ],
      ),
    );
  }
}

==> insuideindoor-1.1.13.tar.gz: example/lib/kkk/splash.dart <==
import 'package:flutter/services.dart';
import 'package:insuideindoor/main.dart';
import 'package:location/location.dart';
import 'package:flutter/material.dart';

import 'package:mapbox_gl/mapbox_gl.dart';

import 'final_home.dart';
// import 'package:mapbox_gl_example/kkk/final_home.dart';
// import 'package:mapbox_gl_example/main.dart';

LatLng GetLatLngFromSP() {
  return LatLng(sharedPreferences.getDouble('latitude')!,
      sharedPreferences.getDouble('longitude')!);
}

class Splash extends StatefulWidget {
  const Splash({Key? key}) : super(key: key);

  @override
  State<Splash> createState() => _SplashState();
}

class _SplashState extends State<Splash> {
  // bool isLoadingIA = true;
  LatLng? IAcoordinates;
  @override
  void initState() {
    super.initState();
    initializeLocationAndSave();
    fetchCurrentLocationViaIA();
  }

  fetchCurrentLocationViaIA() {
    const Channel = MethodChannel("com.mapbox.mapboxglexample");
    const platform = const MethodChannel("com.mapbox.mapboxglexample");

    platform.setMethodCallHandler((call) async {
      print("init state setMethodCallHandler ${call.arguments}");
      // setState(() {
      //   IAcoordinates = call.arguments;
      //   //sharedPreferences.setString('latLng', IAcoordinates.toString());
      // });

      Navigator.pushAndRemoveUntil(
          context,
          // MaterialPageRoute(builder: (_) => MyHome(data: call.arguments)),
          MaterialPageRoute(builder: (_) => FinalHome()),
          // Home2()),
          (route) => false);
    });
  }

  void initializeLocationAndSave() async {
    // Ensure all permissions are collected for Locations
    Location location = Location();
    bool serviceEnabled;
    PermissionStatus? permissionGranted;

    serviceEnabled = await location.serviceEnabled();
    if (!serviceEnabled) {
      serviceEnabled = await location.requestService();
    }

    permissionGranted = await location.hasPermission();
    if (permissionGranted == PermissionStatus.denied) {
      permissionGranted = await location.requestPermission();
    }

    // Get the current user location
    LocationData _locationData = await location.getLocation();
    LatLng currentLocation =
        LatLng(_locationData.latitude!, _locationData.longitude!);

    // Get the current user address
    // String currentAddress =
    //     (await getParsedReverseGeocoding(currentLocation))['place'];

    // Store the user location in sharedPreferences
    sharedPreferences.setDouble('latitude', _locationData.latitude!);
    sharedPreferences.setDouble('longitude', _locationData.longitude!);

    // sharedPreferences.setString('current-address', currentAddress);

    // ignore: use_build_context_synchronously
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: const [
          Center(child: CircularProgressIndicator()),
          SizedBox(height: 20),
          Text("Fetching Location Details")
        ],
      ),
    );
  }
}
